# pyTSPA-toolbox
A Toolbox for Analyzing and Visualizing Team Sports Performance. Including support for multiple data formats, match data segmentation, performance feature extraction, and statistical analysis.

## Installation
### From PyPi
Install `pyTSPA` using pip

```
pip install pyTSPA-toolbox
```

### From source
Clone the git repository
```
git clone https://github.com/vargaheni05/pyTSPA-toolbox.git
```
Change directory to the cloned repository
```
cd pyTSPA-toolbox
```
Install with pip
```
pip install .
```

## Building the documentation
Install required packages
```
pip install -r docs/requirements.txt
```
Call Sphinx build command
```
sphinx-build -M html docs/source docs/build
```
On Windows you can also run the `make.bat` file
```
.\docs\make.bat html
```

The documentation should be available in the `docs/build` directory as html files<br>
This includes the example codes as tutorials

## Correspondence
Henrietta Varga (varga.henrietta.julianna@hallgato.ppke.hu)<br>
Marcell Szögi (szogi.marcell@hallgato.ppke.hu)<br>
Benedek Kardos (kardos.benedek.zoltan@hallgato.ppke.hu)
